@@ -74,7 +74,8 @@ unsigned int dm_major;	/* Device-mapper major number */
 long interval = 0;
 char timestamp[TIMESTAMP_LEN];
 
-struct sigaction alrm_act;
+struct sigaction alrm_act, int_act;
+int sigint_caught = 0;
 
 /*
  ***************************************************************************
@@ -138,6 +139,19 @@ void alarm_handler(int sig)
 	alarm(interval);
 }
 
+/*
+ ***************************************************************************
+ * SIGINT signal handler.
+ *
+ * IN:
+ * @sig	Signal number.
+ **************************************************************************
+ */
+void int_handler(int sig)
+{
+	sigint_caught = 1;
+}
+
 /*
  ***************************************************************************
  * Initialize stats common structures.
@@ -930,16 +944,6 @@ void write_cpu_stat(int curr, int tab)
 {
 	unsigned long long deltot_jiffies;
 
-	/*
-	 * Compute the total number of jiffies spent by all processors.
-	 * NB: Don't add cpu_guest/cpu_guest_nice because cpu_user/cpu_nice
-	 * already include them.
-	 */
-	tot_jiffies[curr] = st_cpu[curr]->cpu_user + st_cpu[curr]->cpu_nice +
-			    st_cpu[curr]->cpu_sys + st_cpu[curr]->cpu_idle +
-			    st_cpu[curr]->cpu_iowait + st_cpu[curr]->cpu_hardirq +
-			    st_cpu[curr]->cpu_steal + st_cpu[curr]->cpu_softirq;
-
 	/* Total number of jiffies spent on the interval */
 	deltot_jiffies = get_interval(tot_jiffies[!curr], tot_jiffies[curr]);
 
@@ -1638,6 +1642,17 @@ void rw_io_stat_loop(long int count, struct tm *rectime)
 		skip = 1;
 	}
 
+	/* Set a handler for SIGALRM */
+	memset(&alrm_act, 0, sizeof(alrm_act));
+	alrm_act.sa_handler = alarm_handler;
+	sigaction(SIGALRM, &alrm_act, NULL);
+	alarm(interval);
+
+	/* Set a handler for SIGINT */
+	memset(&int_act, 0, sizeof(int_act));
+	int_act.sa_handler = int_handler;
+	sigaction(SIGINT, &int_act, NULL);
+
 	/* Don't buffer data if redirected to a pipe */
 	setbuf(stdout, NULL);
 
@@ -1648,6 +1663,16 @@ void rw_io_stat_loop(long int count, struct tm *rectime)
 		/* Read stats for CPU "all" */
 		read_stat_cpu(st_cpu[curr], 1);
 
+		/*
+		 * Compute the total number of jiffies spent by all processors.
+		 * NB: Don't add cpu_guest/cpu_guest_nice because cpu_user/cpu_nice
+		 * already include them.
+		 */
+		tot_jiffies[curr] = st_cpu[curr]->cpu_user + st_cpu[curr]->cpu_nice +
+				    st_cpu[curr]->cpu_sys + st_cpu[curr]->cpu_idle +
+				    st_cpu[curr]->cpu_iowait + st_cpu[curr]->cpu_hardirq +
+				    st_cpu[curr]->cpu_steal + st_cpu[curr]->cpu_softirq;
+
 		if (dlist_idx) {
 			/*
 			 * A device or partition name was explicitly entered
@@ -1690,21 +1715,22 @@ void rw_io_stat_loop(long int count, struct tm *rectime)
 			if (count > 0) {
 				count--;
 			}
-			if (DISPLAY_JSON_OUTPUT(flags)) {
-				if (count) {
-				printf(",");
-				}
-				printf("\n");
-			}
-		}
-		else {
-			skip = 0;
 		}
 
 		if (count) {
 			curr ^= 1;
 			pause();
+
+			if (sigint_caught) {
+				/* SIGINT signal caught => Terminate JSON output properly */
+				count = 0;
+			}
+			else if (DISPLAY_JSON_OUTPUT(flags) && count && !skip) {
+				printf(",");
+			}
+			skip = 0;
 		}
+		printf("\n");
 	}
 	while (count);
 
@@ -1951,7 +1977,7 @@ int main(int argc, char **argv)
 			opt++;
 		}
 
-		else if (!isdigit(argv[opt][0])) {
+		else if (strspn(argv[opt], DIGITS) != strlen(argv[opt])) {
 			/*
 			 * By default iostat doesn't display unused devices.
 			 * If some devices are explicitly entered on the command line
@@ -2058,12 +2084,6 @@ int main(int argc, char **argv)
 		printf("\n");
 	}
 
-	/* Set a handler for SIGALRM */
-	memset(&alrm_act, 0, sizeof(alrm_act));
-	alrm_act.sa_handler = alarm_handler;
-	sigaction(SIGALRM, &alrm_act, NULL);
-	alarm(interval);
-
 	/* Main loop */
 	rw_io_stat_loop(count, &rectime);
 
