@@ -1521,6 +1521,7 @@ __nr_t read_net_eicmp(struct stats_net_eicmp *st_net_eicmp)
 {
 	FILE *fp;
 	char line[1024];
+	static char format[256] = "";
 	int sw = FALSE;
 
 	if ((fp = fopen(NET_SNMP, "r")) == NULL)
@@ -1530,8 +1531,7 @@ __nr_t read_net_eicmp(struct stats_net_eicmp *st_net_eicmp)
 
 		if (!strncmp(line, "Icmp:", 5)) {
 			if (sw) {
-				sscanf(line + 5, "%*u %lu %lu %lu %lu %lu %lu %*u %*u "
-				       "%*u %*u %*u %*u %*u %lu %lu %lu %lu %lu %lu",
+				sscanf(line + 5, format,
 				       &st_net_eicmp->InErrors,
 				       &st_net_eicmp->InDestUnreachs,
 				       &st_net_eicmp->InTimeExcds,
@@ -1548,6 +1548,25 @@ __nr_t read_net_eicmp(struct stats_net_eicmp *st_net_eicmp)
 				break;
 			}
 			else {
+				if (!strlen(format)) {
+					if (strstr(line, "InCsumErrors")) {
+						/*
+						 * New format: InCsumErrors field exists at position #3.
+						 * Capture: 2,4,5,6,7,8,16,17,18,19,20,21
+						 */
+						strcpy(format, "%*u %lu %*u %lu %lu %lu %lu %lu %*u %*u "
+							       "%*u %*u %*u %*u %*u %lu %lu %lu %lu %lu %lu");
+					}
+					else {
+						/*
+						 * Old format: InCsumErrors field doesn't exist.
+						 * Capture: 2,3,4,5,6,7,15,16,17,18,19,20
+						 */
+						strcpy(format, "%*u %lu %lu %lu %lu %lu %lu %*u %*u "
+							       "%*u %*u %*u %*u %*u %lu %lu %lu %lu %lu %lu");
+
+					}
+				}
 				sw = TRUE;
 			}
 		}
@@ -2429,9 +2448,9 @@ __nr_t read_bus_usb_dev(struct stats_pwr_usb *st_pwr_usb, __nr_t nr_alloc)
 __nr_t read_filesystem(struct stats_filesystem *st_filesystem, __nr_t nr_alloc)
 {
 	FILE *fp;
-	char line[512], fs_name[128], mountp[256];
+	char line[512], fs_name[MAX_FS_LEN], mountp[256], type[128];
 	int skip = 0, skip_next = 0;
-	char *pos = 0;
+	char *pos = 0, *pos2 = 0;
 	__nr_t fs_read = 0;
 	struct stats_filesystem *st_filesystem_i;
 	struct statvfs buf;
@@ -2456,6 +2475,19 @@ __nr_t read_filesystem(struct stats_filesystem *st_filesystem, __nr_t nr_alloc)
 			if (pos == NULL)
 				continue;
 
+			/*
+			 * Find second field separator position,
+			 * read filesystem type,
+			 * if filesystem type is autofs, skip it
+			*/
+			pos2 = strchr(pos + 1, ' ');
+			if (pos2 == NULL)
+				continue;
+
+			sscanf(pos2 + 1, "%127s", type);
+			if(strcmp(type, "autofs") == 0)
+				continue;
+
 			/* Read current filesystem name */
 			sscanf(line, "%127s", fs_name);
 			/*
