@@ -987,7 +987,7 @@ void read_stats_from_file(char from_file[])
 	rows = get_win_height();
 
 	/* Read file headers and activity list */
-	check_file_actlst(&ifd, from_file, act, &file_magic, &file_hdr,
+	check_file_actlst(&ifd, from_file, act, flags, &file_magic, &file_hdr,
 			  &file_actlst, id_seq, FALSE, &endian_mismatch, &arch_64);
 
 	/* Perform required allocations */
@@ -1468,7 +1468,7 @@ int main(int argc, char **argv)
 
 	/* 'sar' is equivalent to 'sar -f' */
 	if ((argc == 1) ||
-	    ((interval < 0) && !from_file[0] && !to_file[0])) {
+	    (((interval < 0) || INTERVAL_SET(flags)) && !from_file[0] && !to_file[0])) {
 		set_default_file(from_file, day_offset, -1);
 	}
 
